@@ -33,10 +33,12 @@ from typing import (
 )
 
 # Package imports
+from pathlib import Path
 from enum import Enum, unique
 from asyncio import run
 from datetime import datetime
 from time import mktime
+import os
 from requests import get
 import requests.exceptions
 
@@ -57,12 +59,20 @@ from disspy.core import (
     DisApi,
     DisFlags,
     Snowflake,
-    ChannelId
+    ChannelId,
+    ThreadId,
+    GuildId,
+    UserId
 )
 from disspy.embed import DisEmbed
 from disspy.guild import DisGuild
 from disspy.jsongenerators import _OptionGenerator
 from disspy.user import DisUser
+from disspy.thread import (
+    DisNewsThread,
+    DisThread,
+    DisPrivateThread
+)
 
 __all__: tuple = (
     "DisBotStatus",
@@ -90,6 +100,28 @@ _all_basic_events = [
 ]
 
 
+@final
+class _BotLogger:
+    def __init__(self) -> None:
+        self.logs = []
+
+    def log(self, msg: str):
+        """log
+        Log to Logger
+
+        Args:
+            msg (str): Message
+        """
+        _datetime = datetime.now()
+
+        tformat = "%d/%d/%d %d:%d:%d"
+
+        _time = tformat % (_datetime.year, _datetime.month, _datetime.day,
+                           _datetime.hour, _datetime.minute, _datetime.second)
+
+        self.logs.append(f"[{_time}] {msg}")
+
+
 @final
 @unique
 class DisBotStatus(Enum):
@@ -174,10 +206,8 @@ class DisBot:
 
     __classname__ = "DisBot"
 
-    def __init__(self, token: Snowflake[str], application_id: Optional[Snowflake[int]] = None,
-                status: Optional[TypeOf(DisBotStatus)] = None,
-                flags: Optional[TypeOf(DisFlags)] = None,
-                debug: Optional[bool] = False,
+    def __init__(self, token: Snowflake[str], status: Optional[TypeOf(DisBotStatus)] = None,
+                flags: Optional[TypeOf(DisFlags)] = None, debug: Optional[bool] = False,
                 activity: Optional[Union[Activity, dict]] = None) -> NoReturn:
         """
         Create bot
@@ -213,6 +243,7 @@ class DisBot:
 
         self.status = status
         self._debug = debug
+        self._logger = _BotLogger()
         self._ons = {
             "ready": None,
             "messagec": None,
@@ -238,22 +269,7 @@ class DisBot:
 
         self.user = None
 
-        if application_id is None or application_id == 0:
-            application_id = 0
-        else:
-            _u = f"https://discord.com/api/v10/applications/{application_id}/commands"
-            test2_j = get(_u, headers={'Authorization': f'Bot {token}'}).json()
-
-            try:
-                if test2_j["message"] == "Unknown Application" and test2_j["code"] == 10002:
-                    raise errors.BotApplicationIdInvalid("Invalid Application id!")
-            except KeyError:
-                pass
-            except TypeError:
-                pass
-
-        self.api = DisApi(self.token, self.intflags, application_id)
-        self.application_id: int = int(application_id)
+        self.api = DisApi(self.token, self.intflags)
 
         self.isready = False
 
@@ -262,6 +278,8 @@ class DisBot:
         self.__slots__ = [self.api, self._on_ready, self._on_messagec,
                             self.token, self.user, self.isready, self.status]
 
+        self._logger.log("Bot created succesful!")
+
     async def _on_register(self):
         """
         Register user var
@@ -270,7 +288,7 @@ class DisBot:
         """
         self.user: DisUser = self.api.user
 
-    def _on_close(self):
+    async def _on_close(self):
         pass
 
     def on(self, event_type: Event(DisBotEventType, str)) -> Wrapper:
@@ -294,25 +312,32 @@ class DisBot:
             if event_type in _all_basic_events:
                 if event_type == "close":
                     self._on_close = func
+                    self._logger.log("Register on_close() event")
                 else:
                     if event_type in ["messagec", "messageu", "messaged", "typing", "dm_typing",
                                 "dmessagec", "dmessageu", "dmessaged"]:
                         if self.intflags >= DisFlags.messages():
                             self._ons[event_type] = func
+                            self._logger.log(f"Register on_{event_type}() event")
                         else:
+                            self._logger.log("Error: BotEventVisibleError")
                             raise errors.BotEventVisibleError(
                                 "messagec(), typing(), dm_typing() and other events" +
                                 "don't avaivable right now because flags < DisFlags.messages()")
                     elif event_type in ["reaction", "reactionr"]:
                         if self.intflags >= DisFlags.reactions():
                             self._ons[event_type] = func
+                            self._logger.log(f"Register on_{event_type}() event")
                         else:
+                            self._logger.log("Error: BotEventVisibleError")
                             raise errors.BotEventVisibleError(
                                 "reaction() and reactionr() events don't" +
                                 " avaivable right now because flags < DisFlags.reactions()")
                     else:
                         self._ons[event_type] = func
+                        self._logger.log(f"Register on_{event_type}() event")
             else:
+                self._logger.log("Error: BotEventTypeError")
                 raise errors.BotEventTypeError("Invalid type of event!")
 
         return wrapper
@@ -350,6 +375,7 @@ class DisBot:
         """
 
         def wrapper(func):
+            self._logger.log("Register on_ready() event")
             self._ons["ready"] = func
 
         return wrapper
@@ -376,10 +402,13 @@ class DisBot:
         def wrapper(func):
             if event_type in _ts:
                 if event_type == _ts[0]:  # Message create
+                    self._logger.log("Register on_messagec() event")
                     self._ons[_mse[0]] = func
                 elif event_type == _ts[1]:  # Message update
+                    self._logger.log("Register on_messageu() event")
                     self._ons[_mse[1]] = func
                 elif event_type == _ts[2]:  # Message delete
+                    self._logger.log("Register on_messaged() event")
                     self._ons[_mse[2]] = func
 
         return wrapper
@@ -406,10 +435,13 @@ class DisBot:
         def wrapper(func):
             if event_type in _ts:
                 if event_type == _ts[0]:  # Message create
+                    self._logger.log("Register on_messagec() event")
                     self._ons[_mse[0]] = func
                 elif event_type == _ts[1]:  # Message update
+                    self._logger.log("Register on_messageu() event")
                     self._ons[_mse[1]] = func
                 elif event_type == _ts[2]:  # Message delete
+                    self._logger.log("Register on_messaged() event")
                     self._ons[_mse[2]] = func
 
         return wrapper
@@ -422,13 +454,13 @@ class DisBot:
         :return Wrapper:
         """
         def wrapper(func):
+            self._logger.log("Register on_channel() event")
             self._ons["channel"] = [func, channel_id]
 
         return wrapper
 
     def slash_command(self, name: str, description: str,
-                        options: Optional[List[appc.Option]]
-                        = None) -> Union[Wrapper, None]:
+                      options: Optional[List[appc.Option]] = None) -> Wrapper:
         """
         Create slash command
         -----
@@ -437,34 +469,32 @@ class DisBot:
         :param options: Command's options
         :return Wrapper:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {}
+        _payload = {}
 
-            if options:
-                _options_jsons = []
+        if options:
+            _options_jsons = []
 
-                for option in options:
-                    _options_jsons.append(_OptionGenerator(option))
+            for option in options:
+                _options_jsons.append(_OptionGenerator(option))
 
-                _payload = {
-                    "name": name,
-                    "description": description,
-                    "type": 1,
-                    "options": appc.ApplicationCommandType.TEXT_INPUT
-                }
-            else:
-                _payload = {
-                    "name": name,
-                    "description": description,
-                    "type": appc.ApplicationCommandType.TEXT_INPUT
-                }
+            _payload = {
+                "name": name,
+                "description": description,
+                "type": appc.ApplicationCommandType.TEXT_INPUT,
+                "options": _options_jsons
+            }
+        else:
+            _payload = {
+                "name": name,
+                "description": description,
+                "type": appc.ApplicationCommandType.TEXT_INPUT
+            }
 
-            def wrapper(func):
-                self.api.create_command(_payload, func)
+        def wrapper(func):
+            self._logger.log("Register slash command")
+            self.api.create_command(_payload, func)
 
-            return wrapper
-
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
+        return wrapper
 
     def add_slash_command(self, command: appc.SlashCommand) -> NoReturn:
         """
@@ -473,39 +503,28 @@ class DisBot:
         :param command: Slash Command
         :return None:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {
-                "name": command.name,
-                "description": command.description,
-                "type": appc.ApplicationCommandType.TEXT_INPUT,
-                "options": command.options
-            }
+        self._logger.log("Register slash command")
+        self.api.create_command(command.json(), command.cmd)
 
-            self.api.create_command(_payload, command.cmd)
+        return None
 
-            return None
-
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
-
-    def user_command(self, name) -> Union[Wrapper, None]:
+    def user_command(self, name: str) -> Wrapper:
         """
         Create user command
         -----
         :param name: Command's name
         :return Wrapper:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {
-                "name": name,
-                "type": appc.ApplicationCommandType.USER
-            }
+        _payload = {
+            "name": name,
+            "type": appc.ApplicationCommandType.USER
+        }
 
-            def wrapper(func):
-                self.api.create_command(_payload, func)
+        def wrapper(func):
+            self._logger.log("Register user command")
+            self.api.create_command(_payload, func)
 
-            return wrapper
-
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
+        return wrapper
 
     def add_user_command(self, command: appc.UserCommand) -> NoReturn:
         """
@@ -514,37 +533,28 @@ class DisBot:
         :param command: User Command
         :return None:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {
-                "name": command.name,
-                "type": appc.ApplicationCommandType.USER,
-            }
+        self._logger.log("Register user command")
+        self.api.create_command(command.json(), command.cmd)
 
-            self.api.create_command(_payload, command.cmd)
+        return None
 
-            return None
-
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
-
-    def message_command(self, name) -> Union[Wrapper, None]:
+    def message_command(self, name: str) -> Wrapper:
         """
         Create message command
         -----
         :param name: Command's name
         :return Wrapper:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {
-                "name": name,
-                "type": appc.ApplicationCommandType.MESSAGE
-            }
+        _payload = {
+            "name": name,
+            "type": appc.ApplicationCommandType.MESSAGE
+        }
 
-            def wrapper(func):
-                self.api.create_command(_payload, func)
+        def wrapper(func):
+            self._logger.log("Register message command")
+            self.api.create_command(_payload, func)
 
-            return wrapper
-
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
+        return wrapper
 
     def add_message_command(self,
                             command: appc.MessageCommand) -> NoReturn:
@@ -554,17 +564,22 @@ class DisBot:
         :param command: Message Command
         :return None:
         """
-        if self.application_id != 0 or self.application_id:
-            _payload = {
-                "name": command.name,
-                "type": appc.ApplicationCommandType.MESSAGE,
-            }
+        self._logger.log("Register message command")
+        self.api.create_command(command.json(), command.cmd)
 
-            self.api.create_command(_payload, command.cmd)
+        return None
 
-            return None
+    def add_application_command(self, command: appc.ApplicationCommand) -> NoReturn:
+        """
+        Create application command
+        -----
+        :param command: Application Command
+        :return None:
+        """
+        self._logger.log("Register application command")
+        self.api.create_command(command.json(), command.cmd)
 
-        raise errors.ApplicationIdIsNone("Application commands is blocked")
+        return None
 
     def run(self, status: Optional[Union[DisBotStatus, str]] = None,
             activity: Optional[Union[Activity, dict]] = None) -> NoReturn:
@@ -587,14 +602,18 @@ class DisBot:
         if activity:
             self._act = activity
 
-        self._runner()
+        self._logger.log("Running bot")
 
-    def _runner(self) -> NoReturn:
+        run(self._runner())
+
+    async def _runner(self) -> NoReturn:
         try:
-            run(self.api.run(self.status, self._ons,
-                                debug=self._debug, act=self._act))
+            await self.api.run(self.status, self._ons,
+                               debug=self._debug, act=self._act)
         except KeyboardInterrupt:
-            pass
+            self._write_logs()
+            await self._on_close()
+            await self._dissconnenter()
         except requests.exceptions.ConnectionError:
             raise errors.InternetError("Please turn on your internet!", "-1000")
 
@@ -612,6 +631,7 @@ class DisBot:
 
     async def _dissconnenter(self) -> NoReturn:
         if self.isready:
+            self._logger.log("Disconnect bot")
             await self.api.disconnecter()
 
             for _var in self.__slots__:
@@ -640,7 +660,7 @@ class DisBot:
         :param channel_id: Channel Id
         :return Union[DisChannel, DisDmChannel]:
         """
-        _u = f"https://discord.com/v10/channels/{channel_id}"
+        _u = f"https://discord.com/api/v10/channels/{channel_id}"
         _hdrs = {'Authorization': f'Bot {self.token}'}
 
         j = get(_u, headers=_hdrs).json()
@@ -650,7 +670,37 @@ class DisBot:
 
         return DisChannel(channel_id, self.token)
 
-    def get_guild(self, guild_id: int) -> DisGuild:
+    def get_thread(self, thread_id: ThreadId):
+        """get_thread
+        Get thread by id
+
+        Args:
+            thread_id (ThreadId): Thread id
+
+        Raises:
+            RuntimeError: Argument is not thread id
+
+        Returns:
+            Union[DisNewsThread, DisThread, DisPrivateThread]: Getted thread object
+        """
+        _u = f"https://discord.com/api/v10/channels/{thread_id}"
+        _hdrs = {'Authorization': f'Bot {self.token}',
+                 'content-type': 'application/json'}
+
+        j = get(_u, headers=_hdrs).json()
+
+        if j["type"] == 10:  # News thread
+            return DisNewsThread(j, self.token)
+
+        if j["type"] == 11:  # Public thread
+            return DisThread(j, self.token)
+
+        if j["type"] == 12:  # Private thread
+            return DisPrivateThread(j, self.token)
+
+        raise RuntimeError("This channel is not thread! Use get_channel() method")
+
+    def get_guild(self, guild_id: GuildId) -> DisGuild:
         """
         Get guild from id
         -----
@@ -659,7 +709,7 @@ class DisBot:
         """
         return self.api.get_guild(guild_id)
 
-    def get_user(self, user_id: int) -> DisUser:
+    def get_user(self, user_id: UserId) -> DisUser:
         """
         Get user from id
         -----
@@ -692,5 +742,23 @@ class DisBot:
             }
         })
 
-    def __del__(self):
-        self._on_close()
+    def _write_logs(self):
+        _datetime = datetime.now()
+
+        tformat = "%d %d %d %d %d %d"
+
+        filename = tformat % (_datetime.year, _datetime.month, _datetime.day,
+                              _datetime.hour, _datetime.minute, _datetime.second)
+
+        filename += ".txt"
+
+        current_directory = os.getcwd()
+        final_directory = os.path.join(current_directory, r'__logs__')
+        if not os.path.exists(final_directory):
+            os.makedirs(final_directory)
+
+        path = Path("__logs__") / filename
+
+        with open(path, "x", encoding="utf-8") as file:
+            for i in self._logger.logs:
+                file.write(i + "\n")
