@@ -31,6 +31,8 @@ from typing import (
     List
 )
 
+from enum import Enum
+
 from disspy.reaction import DisEmoji
 from disspy import errors
 
@@ -55,32 +57,31 @@ class Component:
                  min_length=None, max_length=None, placeholder=None, required=None) -> NoReturn:
         if ctype == 1:
             raise errors.MessageComponentIsBlocked("Action Rows don't can to use by users")
-        else:
-            if ctype == 2:
-                if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
-                    raise RuntimeError("Error with creating components!")
-                else:
-                    self.type = ctype
-                    self.custom_id = custom_id
-                    self.label = label
-                    self.style = style
-                    self.url = url
-            elif ctype == 3:
-                self.type = ctype
-                self.custom_id = custom_id
-                self.options = options
-                self.min_values = min_values
-                self.max_values = max_values
-                self.placeholder = placeholder
-            elif ctype == 4:
-                self.type = ctype
-                self.style = style
-                self.label = label
-                self.custom_id = custom_id
-                self.min_length = min_length
-                self.max_length = max_length
-                self.placeholder = placeholder
-                self.required = required
+
+        self.type = ctype
+        self.custom_id = custom_id
+
+        if ctype == 2:
+            if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
+                raise RuntimeError("Error with creating components!")
+
+            self.label = label
+            self.style = style
+            self.url = url
+
+        elif ctype == 3:
+            self.options = options
+            self.min_values = min_values
+            self.max_values = max_values
+            self.placeholder = placeholder
+
+        elif ctype == 4:
+            self.style = style
+            self.label = label
+            self.min_length = min_length
+            self.max_length = max_length
+            self.placeholder = placeholder
+            self.required = required
 
 
 class Button(Component):
@@ -91,13 +92,13 @@ class Button(Component):
                  custom_id: Optional[Text] = None, ) -> NoReturn:
         if not style == 5 and url and not custom_id or style == 5 and not url and custom_id:
             raise RuntimeError("Error with creating buttons!")
-        else:
-            if style is None:  # Default
-                style = 1  # Blue
-            super().__init__(2, custom_id, label, style, url)
+
+        if style is None:  # Default
+            style = 1  # Blue
+        super().__init__(2, custom_id, label, style, url)
 
 
-class ButtonStyle:
+class ButtonStyle(Enum):
     """
     Button styles from official discord docs
     """
@@ -158,12 +159,12 @@ class SelectMenu(Component):
     """
     def __init__(self, custom_id: str, options: List[SelectMenuOption], placeholder: str,
                  min_values: int, max_values: int) -> NoReturn:
-        oj = []
+        options_json = []
 
         for i in options:
-            oj.append(i.json())
+            options_json.append(i.json())
 
-        super().__init__(3, custom_id=custom_id, options=oj, min_values=min_values,
+        super().__init__(3, custom_id=custom_id, options=options_json, min_values=min_values,
                          max_values=max_values, placeholder=placeholder)
 
 
@@ -189,36 +190,40 @@ class TextInputStyle:
 
 
 class _ComponentGenerator:
-    def __new__(cls, c: Component) -> Dict:
-        if c.type == 2:  # Buttons
+    def __new__(cls, component: Component) -> Dict:
+        if component.type == 2:  # Buttons
             return {
-                "type": c.type,
-                "custom_id": c.custom_id,
-                "label": c.label,
-                "style": c.style,
-                "url": c.url
+                "type": component.type,
+                "custom_id": component.custom_id,
+                "label": component.label,
+                "style": component.style,
+                "url": component.url
             }
-        elif c.type == 3:  # Select Menu
+
+        if component.type == 3:  # Select Menu
             return {
-                "type": c.type,
-                "custom_id": c.custom_id,
-                "min_values": c.min_values,
-                "max_values": c.max_values,
-                "placeholder": c.placeholder,
-                "options": c.options
+                "type": component.type,
+                "custom_id": component.custom_id,
+                "min_values": component.min_values,
+                "max_values": component.max_values,
+                "placeholder": component.placeholder,
+                "options": component.options
             }
-        elif c.type == 4:  # Text Input
+
+        if component.type == 4:  # Text Input
             return {
-                "type": c.type,
-                "custom_id": c.custom_id,
-                "style": c.style,
-                "label": c.label,
-                "min_length": c.min_length,
-                "max_length": c.max_length,
-                "placeholder": c.placeholder,
-                "required": c.required
+                "type": component.type,
+                "custom_id": component.custom_id,
+                "style": component.style,
+                "label": component.label,
+                "min_length": component.min_length,
+                "max_length": component.max_length,
+                "placeholder": component.placeholder,
+                "required": component.required
             }
 
+        return {}
+
 
 class ActionRow:
     """
@@ -231,15 +236,15 @@ class ActionRow:
         }]
         self._b = bot
 
-    def add(self, c: Component):
+    def add(self, component: Component):
         """add()
 
         Args:
-            c (Component): Component
+            component (Component): Component
         """
         def wrapper(func):
-            self.json[0]["components"].append(_ComponentGenerator(c))
+            self.json[0]["components"].append(_ComponentGenerator(component))
             self._b = self._b
-            self._b.api.comsevs[c.custom_id] = func
+            self._b.api.comsevs[component.custom_id] = func
 
         return wrapper
